@@ -19,7 +19,6 @@
 
 #include <glib.h>
 #include <glib/gi18n.h>
-#include <url-dispatcher.h>
 
 #include "dbus-end-session-dialog.h"
 #include "dbus-login1-manager.h"
@@ -90,10 +89,29 @@ typedef enum
 {
   PROMPT_NONE,
   PROMPT_WITH_ZENITY,
-  PROMPT_WITH_UNITY
+  PROMPT_WITH_UNITY,
+  PROMPT_WITH_MATE
 }
 prompt_status_t;
 
+static gboolean
+have_mate_program (const gchar *program)
+{
+  const gchar *xdg_current_desktop;
+  g_auto(GStrv) desktop_names = NULL;
+
+  xdg_current_desktop = g_getenv ("XDG_CURRENT_DESKTOP");
+  if (xdg_current_desktop != NULL) {
+    desktop_names = g_strsplit (xdg_current_desktop, ":", 0);
+    if (g_strv_contains ((const gchar * const *) desktop_names, "MATE")) {
+      g_autofree gchar *path = g_find_program_in_path (program);
+      return path != NULL;
+    }
+  }
+
+  return FALSE;
+}
+
 static prompt_status_t
 get_prompt_status (IndicatorSessionActionsDbus * self)
 {
@@ -102,6 +120,10 @@ get_prompt_status (IndicatorSessionActionsDbus * self)
 
   if (!g_settings_get_boolean (p->indicator_settings, "suppress-logout-restart-shutdown"))
     {
+      /* can we use the MATE prompt? */
+      if ((prompt == PROMPT_NONE) && have_mate_program ("mate-session-save"))
+          prompt = PROMPT_WITH_MATE;
+
       /* can we use the Unity prompt? */
       if ((prompt == PROMPT_NONE) && p && p->end_session_dialog)
         {
@@ -228,7 +250,7 @@ on_can_suspend_ready (GObject * o, GAsyncResult * res, gpointer gself)
     {
       priv_t * p = INDICATOR_SESSION_ACTIONS_DBUS(gself)->priv;
 
-      const gboolean b = !g_strcmp0 (str, "yes");
+      const gboolean b = !g_strcmp0 (str, "yes") || !g_strcmp0 (str, "challenge");
 
       if (p->can_suspend != b)
         {
@@ -255,7 +277,7 @@ on_can_hibernate_ready (GObject * o, GAsyncResult * res, gpointer gself)
     {
       priv_t * p = INDICATOR_SESSION_ACTIONS_DBUS(gself)->priv;
 
-      const gboolean b = !g_strcmp0 (str, "yes");
+      const gboolean b = !g_strcmp0 (str, "yes") || !g_strcmp0 (str, "challenge");
 
       if (p->can_hibernate != b)
         {
@@ -454,7 +476,7 @@ my_suspend (IndicatorSessionActions * self)
   g_return_if_fail (p->login1_manager != NULL);
 
   login1_manager_call_suspend (p->login1_manager,
-                               FALSE,
+                               TRUE,
                                p->login1_manager_cancellable,
                                NULL,
                                NULL);
@@ -468,7 +490,7 @@ my_hibernate (IndicatorSessionActions * self)
   g_return_if_fail (p->login1_manager != NULL);
 
   login1_manager_call_hibernate (p->login1_manager,
-                                 FALSE,
+                                 TRUE,
                                  p->login1_manager_cancellable,
                                  NULL,
                                  NULL);
@@ -722,6 +744,15 @@ zenity_question (IndicatorSessionActionsDbus * self,
   return confirmed;
 }
 
+static void
+run_outside_app (const char * cmd)
+{
+  GError * err = NULL;
+  g_debug ("%s calling \"%s\"", G_STRFUNC, cmd);
+  g_spawn_command_line_async (cmd, &err);
+  log_and_clear_error (&err, G_STRLOC, G_STRFUNC);
+}
+
 static void
 my_logout (IndicatorSessionActions * actions)
 {
@@ -733,6 +764,11 @@ my_logout (IndicatorSessionActions * actions)
         show_unity_end_session_dialog (self, END_SESSION_TYPE_LOGOUT);
         break;
 
+      case PROMPT_WITH_MATE:
+        /* --logout-dialog presents Logout and (if available) Switch User options */
+        run_outside_app ("mate-session-save --logout-dialog");
+        break;
+
       case PROMPT_NONE:
         logout_now (self);
         break;
@@ -770,6 +806,11 @@ my_reboot (IndicatorSessionActions * actions)
         show_unity_end_session_dialog (self, END_SESSION_TYPE_REBOOT);
         break;
 
+      case PROMPT_WITH_MATE:
+        /* --shutdown-dialog presents Restart, Shutdown and (if available) Suspend options */
+        run_outside_app ("mate-session-save --shutdown-dialog");
+        break;
+
       case PROMPT_NONE:
         reboot_now (self);
         break;
@@ -799,6 +840,11 @@ my_power_off (IndicatorSessionActions * actions)
         show_unity_end_session_dialog (self, END_SESSION_TYPE_REBOOT);
         break;
 
+      case PROMPT_WITH_MATE:
+        /* --shutdown-dialog presents Restart, Shutdown and (if available) Suspend options */
+        run_outside_app ("mate-session-save --shutdown-dialog");
+        break;
+
       case PROMPT_WITH_ZENITY:
         if (zenity_question (self,
               "system-shutdown",
@@ -819,20 +865,11 @@ my_power_off (IndicatorSessionActions * actions)
 ****
 ***/
 
-static void
-run_outside_app (const char * cmd)
-{
-  GError * err = NULL;
-  g_debug ("%s calling \"%s\"", G_STRFUNC, cmd);
-  g_spawn_command_line_async (cmd, &err);
-  log_and_clear_error (&err, G_STRLOC, G_STRFUNC);
-}
-
 static void
 my_help (IndicatorSessionActions * self G_GNUC_UNUSED)
 {
-  if (g_getenv ("MIR_SOCKET") != NULL)
-    url_dispatch_send("http://www.askubuntu.com", NULL, NULL);
+  if (have_mate_program ("yelp"))
+    run_outside_app ("yelp help:mate-user-guide");
   else
     run_outside_app ("yelp");
 }
@@ -872,10 +909,10 @@ have_unity_control_center (void)
 static void
 my_settings (IndicatorSessionActions * self G_GNUC_UNUSED)
 {
-  if (g_getenv ("MIR_SOCKET") != NULL)
-    url_dispatch_send("settings:///system", NULL, NULL);
-  else if (have_unity_control_center ())
+  if (have_unity_control_center ())
     run_outside_app ("unity-control-center");
+  else if (have_mate_program ("mate-control-center"))
+    run_outside_app ("mate-control-center");
   else
     run_outside_app ("gnome-control-center");
 }
@@ -883,23 +920,21 @@ my_settings (IndicatorSessionActions * self G_GNUC_UNUSED)
 static void
 my_online_accounts (IndicatorSessionActions * self G_GNUC_UNUSED)
 {
-  if (g_getenv ("MIR_SOCKET") != NULL)
-    url_dispatch_send("settings:///system/online-accounts", NULL, NULL);
-  else if (have_unity_control_center ())
+  if (have_unity_control_center ())
     run_outside_app ("unity-control-center credentials");
   else
-    run_outside_app ("gnome-control-center credentials");
+    run_outside_app ("gnome-control-center online-accounts");
 }
 
 static void
 my_about (IndicatorSessionActions * self G_GNUC_UNUSED)
 {
-  if (g_getenv ("MIR_SOCKET") != NULL)
-    url_dispatch_send("settings:///system/about", NULL, NULL);
-  else if (have_unity_control_center ())
+  if (have_unity_control_center ())
     run_outside_app ("unity-control-center info");
+  else if (have_mate_program ("mate-system-monitor"))
+    run_outside_app ("mate-system-monitor --show-system-tab");
   else
-    run_outside_app ("gnome-control-center info");
+    run_outside_app ("gnome-control-center info-overview");
 }
 
 /***
@@ -922,6 +957,10 @@ lock_current_session (IndicatorSessionActions * self, gboolean immediate)
           unity_session_call_lock (p->unity_session, p->cancellable, NULL, NULL);
         }
     }
+  else if (have_mate_program ("mate-screensaver-command"))
+    {
+      run_outside_app ("mate-screensaver-command --lock");
+    }
   else
     {
       g_return_if_fail (p->screen_saver != NULL);
