@@ -20,8 +20,9 @@
 #include <glib/gi18n.h>
 #include <gio/gio.h>
 
+#include <libwhoopsie/recoverable-problem.h>
+
 #include "backend.h"
-#include "recoverable-problem.h"
 #include "service.h"
 
 #define BUS_NAME "com.canonical.indicator.session"
@@ -425,7 +426,7 @@ get_distro_name (void)
 static gboolean
 usage_mode_to_action_state(GValue *value,
                            GVariant *variant,
-                           gpointer unused)
+                           gpointer unused G_GNUC_UNUSED)
 {
   const gchar* usage_mode = g_variant_get_string(variant, NULL);
   GVariant* ret_var = g_variant_new_boolean(g_strcmp0(usage_mode, "Windowed") == 0 ? TRUE : FALSE);
@@ -435,8 +436,8 @@ usage_mode_to_action_state(GValue *value,
 
 static GVariant*
 action_state_to_usage_mode(const GValue *value,
-                           const GVariantType * unused_expected_type,
-                           gpointer unused)
+                           const GVariantType * unused_expected_type G_GNUC_UNUSED,
+                           gpointer unused G_GNUC_UNUSED)
 {
   GVariant* var = g_value_get_variant(value);
   GVariant* ret = g_variant_new_string(g_variant_get_boolean(var) == TRUE ? "Windowed" : "Staged");
@@ -467,7 +468,7 @@ create_admin_section (IndicatorSessionService * self)
   if (p->usage_mode_action && g_getenv ("MIR_SOCKET") != NULL) // only under unity8
   {
       GMenuItem * menu_item = NULL;
-      menu_item = g_menu_item_new(_("Desktop mode"), "indicator.usage-mode");
+      menu_item = g_menu_item_new(_("Desktop Mode"), "indicator.usage-mode");
       g_menu_item_set_attribute(menu_item, "x-canonical-type", "s", "com.canonical.indicator.switch");
       g_menu_append_item(menu, menu_item);
       g_object_unref(menu_item);
@@ -638,34 +639,24 @@ report_unusable_user (IndicatorSessionService * self, const IndicatorSessionUser
 
   if (!g_hash_table_contains (p->reported_users, key))
   {
-    gchar * uid_str;
-    GPtrArray * additional;
-    const gchar * const error_name = "indicator-session-unknown-user-error";
+    gchar * uid_str = g_strdup_printf("%u", u->uid);
 
-    /* don't spam apport with duplicates */
+    const char * properties[] = {
+        "uid", uid_str,
+        "icon_file", (u->icon_file ? u->icon_file : "(null)"),
+        "is_current_user", (u->is_current_user ? "true" : "false"),
+        "is_logged_in", (u->is_logged_in ? "true" : "false"),
+        "real_name", (u->real_name ? u->real_name : "(null)"),
+        "user_name", (u->user_name ? u->user_name : "(null)"),
+        NULL
+    };
+
+    whoopsie_report_recoverable_problem("indicator-session-unknown-user-error", 0, FALSE, properties);
+
+    /* mark it as reported so that we'll only report it once */
     g_hash_table_add (p->reported_users, key);
 
-    uid_str = g_strdup_printf("%u", u->uid);
-
-    additional = g_ptr_array_new (); /* null-terminated key/value pair strs */
-    g_ptr_array_add (additional, "uid");
-    g_ptr_array_add (additional, uid_str);
-    g_ptr_array_add (additional, "icon_file");
-    g_ptr_array_add (additional, u->icon_file ? u->icon_file : "(null)");
-    g_ptr_array_add (additional, "is_current_user");
-    g_ptr_array_add (additional, u->is_current_user ? "true" : "false");
-    g_ptr_array_add (additional, "is_logged_in");
-    g_ptr_array_add (additional, u->is_logged_in ? "true" : "false");
-    g_ptr_array_add (additional, "real_name");
-    g_ptr_array_add (additional, u->real_name ? u->real_name : "(null)");
-    g_ptr_array_add (additional, "user_name");
-    g_ptr_array_add (additional, u->user_name ? u->user_name : "(null)");
-    g_ptr_array_add (additional, NULL); /* null termination */
-    report_recoverable_problem(error_name, (GPid)0, FALSE, (gchar**)additional->pdata);
-
-    /* cleanup */
     g_free (uid_str);
-    g_ptr_array_free (additional, TRUE);
   }
 }
 
@@ -1307,7 +1298,7 @@ indicator_session_service_init (IndicatorSessionService * self)
                                    INDICATOR_TYPE_SESSION_SERVICE,
                                    IndicatorSessionServicePrivate);
   p->indicator_settings = g_settings_new ("com.canonical.indicator.session");
-  p->keybinding_settings = g_settings_new ("org.gnome.settings-daemon.plugins.media-keys");
+  p->keybinding_settings = g_settings_new ("com.canonical.unity.settings-daemon.plugins.media-keys");
 
   /* Only use unity8 schema if it's installed; this avoids a hard dependency
      on unity8-schemas */
